DebugClients/Python/DCTestResult.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 790
2c0ea0163ef4
child 792
a13346916170
--- a/DebugClients/Python/DCTestResult.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/DebugClients/Python/DCTestResult.py	Sat Jan 02 17:09:08 2010 +0000
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a TestResult derivative for the eric4 debugger.
+Module implementing a TestResult derivative for the eric5 debugger.
 """
 
 import select
@@ -17,7 +17,7 @@
 
 class DCTestResult(TestResult):
     """
     A TestResult derivative to work with eric4's debug client.
     
     For more details see unittest.py of the standard python distribution.
     """
@@ -77,4 +77,4 @@
         rrdy, wrdy, xrdy = select.select([self.parent.readstream],[],[], 0.01)
 
         if self.parent.readstream in rrdy:
-            self.parent.readReady(self.parent.readstream.fileno())
+            self.parent.readReady(self.parent.readstream.fileno())
\ No newline at end of file
@@ -17,7 +17,7 @@
 class DCTestResult(TestResult):
     """
-    A TestResult derivative to work with eric4's debug client.
+    A TestResult derivative to work with eric5's debug client.
     
     For more details see unittest.py of the standard python distribution.

eric ide

mercurial